==> react-molecule-autosuggest-field-2.8.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { jsx as _jsx } from "react/jsx-runtime";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import { useRef } from 'react';
import PropTypes from 'prop-types';
import MoleculeField from '@s-ui/react-molecule-field';
import MoleculeAutosuggest, { MoleculeAutosuggestStates, MoleculeAutosuggestDropdownListSizes } from '@s-ui/react-molecule-autosuggest';

var getErrorState = function getErrorState(_ref) {
  var successText = _ref.successText,
      errorText = _ref.errorText;
  if (successText) return false;
  if (errorText) return true;
};

var getState = function getState(_ref2) {
  var successText = _ref2.successText,
      errorState = _ref2.errorState,
      alertText = _ref2.alertText;
  if (successText) return MoleculeAutosuggestStates.SUCCESS;
  if (errorState) return MoleculeAutosuggestStates.ERROR;
  if (alertText) return MoleculeAutosuggestStates.ALERT;
};

function MoleculeAutosuggestField(_ref3) {
  var alertText = _ref3.alertText,
      children = _ref3.children,
      errorText = _ref3.errorText,
      helpText = _ref3.helpText,
      id = _ref3.id,
      inline = _ref3.inline,
      label = _ref3.label,
      onChange = _ref3.onChange,
      successText = _ref3.successText,
      useContrastLabel = _ref3.useContrastLabel,
      restProps = _objectWithoutPropertiesLoose(_ref3, ["alertText", "children", "errorText", "helpText", "id", "inline", "label", "onChange", "successText", "useContrastLabel"]);

  var refAutosuggest = useRef();

  var handleClick = function handleClick() {
    var domAutosuggest = refAutosuggest.current;
    if (domAutosuggest) domAutosuggest.focus();
  };

  var errorState = getErrorState({
    successText: successText,
    errorText: errorText
  });
  var autosuggestState = getState({
    successText: successText,
    errorState: errorState,
    alertText: alertText
  });
  return /*#__PURE__*/_jsx(MoleculeField, {
    name: id,
    label: label,
    successText: successText,
    errorText: errorText,
    alertText: alertText,
    helpText: helpText,
    inline: inline,
    onClickLabel: handleClick,
    onChange: onChange,
    useContrastLabel: useContrastLabel,
    children: /*#__PURE__*/_jsx(MoleculeAutosuggest, _extends({
      id: id,
      refMoleculeAutosuggest: refAutosuggest,
      errorState: errorState,
      state: autosuggestState
    }, restProps, {
      children: children
    }))
  });
}

MoleculeAutosuggestField.displayName = 'MoleculeAutosuggestField';
export default MoleculeAutosuggestField;
export { MoleculeAutosuggestStates, MoleculeAutosuggestDropdownListSizes };

==> react-molecule-autosuggest-field-2.9.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["alertText", "children", "errorText", "helpText", "id", "inline", "label", "nodeLabel", "onChange", "successText", "useContrastLabel"];
import { useRef } from 'react';
import PropTypes from 'prop-types';
import MoleculeField from '@s-ui/react-molecule-field';
import MoleculeAutosuggest, { MoleculeAutosuggestStates, MoleculeAutosuggestDropdownListSizes } from '@s-ui/react-molecule-autosuggest';
import { jsx as _jsx } from "react/jsx-runtime";

var getErrorState = function getErrorState(_ref) {
  var successText = _ref.successText,
      errorText = _ref.errorText;
  if (successText) return false;
  if (errorText) return true;
};

var getState = function getState(_ref2) {
  var successText = _ref2.successText,
      errorState = _ref2.errorState,
      alertText = _ref2.alertText;
  if (successText) return MoleculeAutosuggestStates.SUCCESS;
  if (errorState) return MoleculeAutosuggestStates.ERROR;
  if (alertText) return MoleculeAutosuggestStates.ALERT;
};

function MoleculeAutosuggestField(_ref3) {
  var alertText = _ref3.alertText,
      children = _ref3.children,
      errorText = _ref3.errorText,
      helpText = _ref3.helpText,
      id = _ref3.id,
      inline = _ref3.inline,
      label = _ref3.label,
      nodeLabel = _ref3.nodeLabel,
      onChange = _ref3.onChange,
      successText = _ref3.successText,
      useContrastLabel = _ref3.useContrastLabel,
      restProps = _objectWithoutPropertiesLoose(_ref3, _excluded);

  var refAutosuggest = useRef();

  var handleClick = function handleClick() {
    var domAutosuggest = refAutosuggest.current;
    if (domAutosuggest) domAutosuggest.focus();
  };

  var errorState = getErrorState({
    successText: successText,
    errorText: errorText
  });
  var autosuggestState = getState({
    successText: successText,
    errorState: errorState,
    alertText: alertText
  });
  return /*#__PURE__*/_jsx(MoleculeField, {
    name: id,
    label: label,
    nodeLabel: nodeLabel,
    successText: successText,
    errorText: errorText,
    alertText: alertText,
    helpText: helpText,
    inline: inline,
    onClickLabel: handleClick,
    onChange: onChange,
    useContrastLabel: useContrastLabel,
    children: /*#__PURE__*/_jsx(MoleculeAutosuggest, _extends({
      id: id,
      refMoleculeAutosuggest: refAutosuggest,
      errorState: errorState,
      state: autosuggestState
    }, restProps, {
      children: children
    }))
  });
}

MoleculeAutosuggestField.displayName = 'MoleculeAutosuggestField';
export default MoleculeAutosuggestField;
export { MoleculeAutosuggestStates, MoleculeAutosuggestDropdownListSizes };
